==> OpenOLAP_V1.0.zip: OpenOLAP/src/metatool/MTCreateTask.java <==
import java.util.*;
import java.io.*;

import java.sql.*;
import java.sql.SQLException;

public class MTCreateTask {
	private int lengthOfTask;
	private int current = 0;
	private String statMessage;

	private String url;
	private String user;
	private String password;
	private String schema;

	MTActualTask mtat = null;

	Statement stmt = null;
	CallableStatement cstmt = null;

	// SQLXNvg̊Ǘ
	static final int iMaxScript = 200;
	String[] script = null;
	static final int iMaxProc1  = 50;
	String[] proc1 = null;
	String[] proc2 = null;
	String[] proc3 = null;
	static final int iMaxTime1  = 100;
	String[] time = null;

	//DB Status
	int iRetValue;
	String strRetValue;

	// ݏ̃^XNNo.(Work)
	int iCurrentCount = 0;
	// ׂẴ^XN(Work)
	int iTotalCount = 0;

	public MTCreateTask(Hashtable C3Hash) {
		//Xe[^X
		iRetValue = 0;
		strRetValue = "";

		//Compute length of task...
		//In a real program, this would figure out
		//the number of bytes to read or whatever.

		//^XNǗ
		//ϐEz̏
		script = new String[iMaxScript];
		proc1   = new String[iMaxProc1];
		proc2   = new String[iMaxProc1];
		proc3   = new String[iMaxProc1];
		time   = new String[iMaxTime1];
		for (int iCount = 0; iCount < iMaxScript; iCount++) { script[iCount] = ""; }
		for (int iCount = 0; iCount < iMaxProc1;  iCount++) { proc1[iCount]  = ""; }
		for (int iCount = 0; iCount < iMaxProc1;  iCount++) { proc2[iCount]  = ""; }
		for (int iCount = 0; iCount < iMaxProc1;  iCount++) { proc3[iCount]  = ""; }
		for (int iCount = 0; iCount < iMaxTime1;  iCount++) { time[iCount]  = ""; }

		iTotalCount  = 0;
		iTotalCount += this.init_script();
		iTotalCount += this.init_proc1();
		iTotalCount += this.init_proc2();
		iTotalCount += this.init_proc3();
		iTotalCount += this.init_time();
		lengthOfTask = iTotalCount;

		//JDBCڑpp[^ݒ
		url = "jdbc:postgresql://";
		url = url + (String)C3Hash.get("HOST") + ":";
		url = url + (String)C3Hash.get("PORT") + "/";
		url = url + (String)C3Hash.get("SID");

		user = (String)C3Hash.get("USER");
		password = (String)C3Hash.get("PASS");
		schema = (String)C3Hash.get("SCHM");

		// \bZ[W
		statMessage = "ڑ...";
	}

    /**
     * Called from ProgressBarDemo to start the task.
     */
    void go() {
        current = 0;
Dbg.out("url:"+url);
Dbg.out("user:"+user);
Dbg.out("password:"+password);
        final SwingWorker worker = new SwingWorker() {
            public Object construct() {
				mtat = new MTActualTask(url, user, password,schema);
				return mtat;
            }
        };
        worker.start();
    }

    /**
     * Called from ProgressBarDemo to find out how much work needs
     * to be done.
     */
    int getLengthOfTask() {
		return lengthOfTask;
    }

    /**
     * Called from ProgressBarDemo to find out how much has been done.
     */
    int getCurrent() {
		return current;
    }

    void stop() {
        current = lengthOfTask;
    }

    /**
     * Called from ProgressBarDemo to find out if the task has completed. i^XN̔j
     */
    boolean done() {
        if (current >= lengthOfTask)
            return true;
        else
            return false;
    }

    String getMessage() {
        return statMessage;
    }

	// ^XNEXe[^XǗ\bh
	int getIntStatus() {
		return iRetValue;
	}
	String getStringStatus() {
		return strRetValue;
	}
	void initStatus() {
		iRetValue = 0;
		strRetValue = "";
	}

	//JDBCڑp[^̍ĐݒiEBU[hŖ߂ƂɍĐݒ肪KvȂ̂ŊOĂяo郁\bhƂėpӁj
	void setValue(Hashtable C3Hash) {
		url = "jdbc:postgresql://";
		url = url + (String)C3Hash.get("HOST") + ":";
		url = url + (String)C3Hash.get("PORT") + "/";
		url = url + (String)C3Hash.get("SID");

		user = (String)C3Hash.get("USER");
		password = (String)C3Hash.get("PASS");
		schema = (String)C3Hash.get("SCHM");
	}

	// NX͂
	class MTActualTask {
		MTActualTask (String strUrl, String strUser, String strPassword,String strSchema) {
			// ݒ

			url      = strUrl;
			user     = strUser;
			password = strPassword;
			schema   = strSchema;
			// ^XN̎sJn
			//iRetValue = this.execute();
			this.execute();
		}

		void execute() {
			//bZ[W\pɑҋ@
			try {
				Thread.sleep(1000); //sleep for a second
			} catch (InterruptedException e) {}

			// hCoNX[h
			try {
				Class.forName("org.postgresql.Driver");
			} catch (Exception e) {
				System.out.println("Caught exception " + e +".");
				iRetValue = 100;
				strRetValue = (String)e.getMessage();
			}

			// f[^x[X֐ڑ
			Connection conn = null;
			try {
				conn = (Connection)java.sql.DriverManager.getConnection(url, user, password);
			} catch (SQLException e) {
				System.out.println("Connection attempt failed.");
				e.printStackTrace();
				iRetValue = 110;
				strRetValue = (String)e.getMessage();
			}

			// Xe[ggIuWFNg𐶐
			try {
				stmt = conn.createStatement();
			} catch (SQLException e) {
				System.out.println("Caught exception " + e +".");
				iRetValue = 120;
				strRetValue = (String)e.getMessage();
			}

			// *********************
			// Processing.....start
			// *********************

			int iRecCount=0;
			String sql = "SELECT count(*) as rec_cnt FROM pg_namespace where nspname ='"+schema+"'";
			try {
				ResultSet rs = stmt.executeQuery(sql);
				while(rs.next()) {
					iRecCount = rs.getInt("rec_cnt");
				}
				if (iRecCount == 0) {
					iRetValue = 1000;
					strRetValue = schema+"XL[}݂܂B";
					//f
					return;
				}
			} catch (SQLException e) {
				System.out.println("Caught exception " + e +".");
			}

			//^e[uǗpSQL
			sql = "select count(*) as rec_cnt from "+schema+".oo_meta_info";
			iRecCount = -1; // 0 ȉɂĂāAR[h擾łȂꍇƋʁiÔ߁j
			//R[h̗L
			try {
				ResultSet rs = stmt.executeQuery(sql);
				while(rs.next()) {
					iRecCount = rs.getInt("rec_cnt");
				}
			} catch (SQLException e) {
				//e[u݂Ȃꍇ͉Ȃi߂Ă̐ݒj
			}

			// iRecCount = -1 -> e[u݂Ȃ(Creates)
			// iRecCount =  0 -> e[u(Creates)
			if (iRecCount > 0) {
				iRetValue = 1000;
				strRetValue = "łɃ^f[^݂܂B";
				//f
				return;
			}

			//XNvgs
			for (int iCount = 0; iCount < script.length; iCount++) {
				try {
					if (!script[iCount].equals("")) {
try {
	Thread.sleep(500); //sleep for a second
} catch (InterruptedException e) {}
						iCurrentCount++; // JEgAbv
						current = iCurrentCount;
						statMessage = current + "^" + lengthOfTask + " I܂B";
						script[iCount]=replace(script[iCount],"%schema%",schema);
						stmt.executeUpdate(script[iCount]);
					}
				} catch (SQLException e) {
Dbg.out("Error"+script[iCount]+e.toString());
				}
			}

			for (int iCount = 0; iCount < proc1.length; iCount++) {
				try {
					if (!proc1[iCount].equals("")) {
try {
	Thread.sleep(500); //sleep for a second
} catch (InterruptedException e) {}
						iCurrentCount++; // JEgAbv
						current = iCurrentCount;
						statMessage = current + "^" + lengthOfTask + " I܂B";
						proc1[iCount]=replace(proc1[iCount],"%schema%",schema);
						stmt.executeUpdate(proc1[iCount]);
					}
				} catch (SQLException e) {
Dbg.out("Error"+proc1[iCount]+e.toString());
				}
			}

			for (int iCount = 0; iCount < proc2.length; iCount++) {
				try {
					if (!proc2[iCount].equals("")) {
try {
	Thread.sleep(500); //sleep for a second
} catch (InterruptedException e) {}
						iCurrentCount++; // JEgAbv
						current = iCurrentCount;
						statMessage = current + "^" + lengthOfTask + " I܂B";
						proc2[iCount]=replace(proc2[iCount],"%schema%",schema);
						stmt.executeUpdate(proc2[iCount]);
					}
				} catch (SQLException e) {
Dbg.out("Error"+proc2[iCount]+e.toString());
				}
			}

			for (int iCount = 0; iCount < proc3.length; iCount++) {
				try {
					if (!proc3[iCount].equals("")) {
try {
	Thread.sleep(500); //sleep for a second
} catch (InterruptedException e) {}
						iCurrentCount++; // JEgAbv
						current = iCurrentCount;
						statMessage = current + "^" + lengthOfTask + " I܂B";
						proc3[iCount]=replace(proc3[iCount],"%schema%",schema);
						stmt.executeUpdate(proc3[iCount]);
					}
				} catch (SQLException e) {
Dbg.out("Error"+proc3[iCount]+e.toString());
				}
			}

			for (int iCount = 0; iCount < time.length; iCount++) {
				try {
					if (!time[iCount].equals("")) {
try {
	Thread.sleep(500); //sleep for a second
} catch (InterruptedException e) {}
						iCurrentCount++; // JEgAbv
						current = iCurrentCount;
						statMessage = current + "^" + lengthOfTask + " I܂B";
						time[iCount]=replace(time[iCount],"%schema%",schema);
						ResultSet rs = stmt.executeQuery(time[iCount]);
						rs.close();
					}
				} catch (SQLException e) {
Dbg.out("Error"+proc3[iCount]+e.toString());
				}
			}

			//
			// Processing.....end
			// 

			// f[^x[Xؒf
			try {
				cstmt.close();
				stmt.close();
				conn.close();
			} catch (SQLException e) {
				System.out.println("Caught exception " + e +".");
				iRetValue = 199;
				strRetValue = (String)e.getMessage();
			}

			//bZ[W\pɑҋ@
			try {
				Thread.sleep(1000); //sleep for a second
			} catch (InterruptedException e) {}
			iRetValue = 0;
			strRetValue = "";
		}
	}
	// NX͂܂

	String readFile (String pathName){
		try{
			//FileReader fr = new FileReader(pathName);
			//BufferedReader br = new BufferedReader(fr);

			FileInputStream fis = new FileInputStream(pathName);
			InputStreamReader isr = null;
				isr = new InputStreamReader(fis,"Shift_JIS");
				//isr = new InputStreamReader(fis);

			BufferedReader br = new BufferedReader(isr);

			String line="";
			String allText="";

			line = "";
//			allText = line + "\n";
			while(line != null){
				line = br.readLine();
				if (line !=null){
					allText += line + "\n";
				}
			}
			return allText;
		}catch(FileNotFoundException e){
		}catch(IOException e){
		}
		return null;
	}

	int init_script() {
	    script = split(this.readFile("createMetaTable.oo"), "/"+"\n");
		return script.length -1 ;
	}

	int init_proc1() {
	    proc1 = split(this.readFile("createProcedure1.oo"), "/"+"\n");
		return proc1.length -1 ;
	}

	int init_proc2() {
	    proc2 = split(this.readFile("createProcedure2.oo"), "/"+"\n");
		return proc2.length -1 ;
	}

	int init_proc3() {
	    proc3 = split(this.readFile("createProcedure3.oo"), "/"+"\n");
		return proc3.length -1 ;
	}

	int init_time() {
	    time = split(this.readFile("createTimeData.oo"), "/"+"\n");
		return time.length -1 ;
	}

	private static String replace(String strTarget, String strOldStr, String strOldNew){
	    String strSplit[];
	    String strResult;

	    strSplit = split(strTarget, strOldStr);
	    strResult = strSplit[0];
	    for (int i = 1; i < strSplit.length; i ++)
	    {
	        strResult += strOldNew + strSplit[i];
	    }

	    return strResult;
	}

	private static String[] split(String strTarget, String strDelimiter){
	    String strResult[];
	    Vector objResult;
	    int intDelimiterLen;
	    int intStart;
	    int intEnd;

	    objResult = new java.util.Vector();
	    strTarget = strTarget + strDelimiter;
	    intDelimiterLen = strDelimiter.length();
	    intStart = 0;
	    while ((intEnd = strTarget.indexOf(strDelimiter, intStart)) >= 0)
	    {
	        objResult.addElement(strTarget.substring(intStart, intEnd));
	        intStart = intEnd + intDelimiterLen;
	    }

	    strResult = new String[objResult.size()];
	    objResult.copyInto(strResult);
	    return strResult;
	}


}

==> OpenOLAP_V1.2.1.zip: OpenOLAP/src/metatool/MTCreateTask.java <==
import java.util.*;
import java.io.*;

import java.sql.*;
import java.sql.SQLException;

public class MTCreateTask {
	private int lengthOfTask;
	private int current = 0;
	private String statMessage;

	private String url;
	private String user;
	private String password;
	private String schema;

	MTActualTask mtat = null;

	Statement stmt = null;
//	CallableStatement cstmt = null;

	// SQLXNvg̊Ǘ
	static final int iMaxScript = 200;
	String[] script = null;
	static final int iMaxProc  = 100;
	String[] proc = null;
	static final int iMaxTime  = 100;
	String[] time = null;

	//DB Status
	int iRetValue;
	String strRetValue;

	// ݏ̃^XNNo.(Work)
	int iCurrentCount = 0;
	// ׂẴ^XN(Work)
	int iTotalCount = 0;

	public MTCreateTask(Hashtable C3Hash) {
		//Xe[^X
		iRetValue = 0;
		strRetValue = "";

		//Compute length of task...
		//In a real program, this would figure out
		//the number of bytes to read or whatever.

		//^XNǗ
		//ϐEz̏
		script = new String[iMaxScript];
		proc   = new String[iMaxProc];
		time   = new String[iMaxTime];
		for (int iCount = 0; iCount < iMaxScript; iCount++) { script[iCount] = ""; }
		for (int iCount = 0; iCount < iMaxProc;  iCount++) { proc[iCount]  = ""; }
		for (int iCount = 0; iCount < iMaxTime;  iCount++) { time[iCount]  = ""; }

		iTotalCount  = 0;
		iTotalCount += this.init_script();
		iTotalCount += this.init_proc();
		iTotalCount += this.init_time();
		lengthOfTask = iTotalCount;

		//JDBCڑpp[^ݒ
		url = "jdbc:postgresql://";
		url = url + (String)C3Hash.get("HOST") + ":";
		url = url + (String)C3Hash.get("PORT") + "/";
		url = url + (String)C3Hash.get("SID");

		user = (String)C3Hash.get("USER");
		password = (String)C3Hash.get("PASS");
		schema = (String)C3Hash.get("SCHM");

		// \bZ[W
		statMessage = "ڑ...";
	}

    /**
     * Called from ProgressBarDemo to start the task.
     */
    void go() {
        current = 0;
Dbg.out("url:"+url);
Dbg.out("user:"+user);
Dbg.out("password:"+password);
        final SwingWorker worker = new SwingWorker() {
            public Object construct() {
				mtat = new MTActualTask(url, user, password,schema);
				return mtat;
            }
        };
        worker.start();
    }

    /**
     * Called from ProgressBarDemo to find out how much work needs
     * to be done.
     */
    int getLengthOfTask() {
		return lengthOfTask;
    }

    /**
     * Called from ProgressBarDemo to find out how much has been done.
     */
    int getCurrent() {
		return current;
    }

    void stop() {
        current = lengthOfTask;
    }

    /**
     * Called from ProgressBarDemo to find out if the task has completed. i^XN̔j
     */
    boolean done() {
        if (current >= lengthOfTask)
            return true;
        else
            return false;
    }

    String getMessage() {
        return statMessage;
    }

	// ^XNEXe[^XǗ\bh
	int getIntStatus() {
		return iRetValue;
	}
	String getStringStatus() {
		return strRetValue;
	}
	void initStatus() {
		iRetValue = 0;
		strRetValue = "";
	}

	//JDBCڑp[^̍ĐݒiEBU[hŖ߂ƂɍĐݒ肪KvȂ̂ŊOĂяo郁\bhƂėpӁj
	void setValue(Hashtable C3Hash) {
		url = "jdbc:postgresql://";
		url = url + (String)C3Hash.get("HOST") + ":";
		url = url + (String)C3Hash.get("PORT") + "/";
		url = url + (String)C3Hash.get("SID");

		user = (String)C3Hash.get("USER");
		password = (String)C3Hash.get("PASS");
		schema = (String)C3Hash.get("SCHM");
	}

	// NX͂
	class MTActualTask {
		MTActualTask (String strUrl, String strUser, String strPassword,String strSchema) {
			// ݒ

			url      = strUrl;
			user     = strUser;
			password = strPassword;
			schema   = strSchema;
			// ^XN̎sJn
			//iRetValue = this.execute();
			this.execute();
		}

		void execute() {
			//bZ[W\pɑҋ@
			try {
				Thread.sleep(1000); //sleep for a second
			} catch (InterruptedException e) {}

			// hCoNX[h
			try {
				Class.forName("org.postgresql.Driver");
			} catch (Exception e) {
				System.out.println("Caught exception " + e +".");
				iRetValue = 100;
				strRetValue = (String)e.getMessage();
			}

			// f[^x[X֐ڑ
			Connection conn = null;
			try {
				conn = (Connection)java.sql.DriverManager.getConnection(url, user, password);
			} catch (SQLException e) {
				System.out.println("Connection attempt failed.");
				e.printStackTrace();
				iRetValue = 110;
				strRetValue = (String)e.getMessage();
			}

			// Xe[ggIuWFNg𐶐
			try {
				stmt = conn.createStatement();
			} catch (SQLException e) {
				System.out.println("Caught exception " + e +".");
				iRetValue = 120;
				strRetValue = (String)e.getMessage();
			}

			// *********************
			// Processing.....start
			// *********************

			int iRecCount=0;
			String sql = "SELECT count(*) as rec_cnt FROM pg_namespace where nspname ='"+schema+"'";
			try {
				ResultSet rs = stmt.executeQuery(sql);
				while(rs.next()) {
					iRecCount = rs.getInt("rec_cnt");
				}
				if (iRecCount == 0) {
					iRetValue = 1000;
					strRetValue = schema+"XL[}݂܂B";
					//f
					return;
				}
			} catch (SQLException e) {
				System.out.println("Caught exception " + e +".");
			}

			//^e[uǗpSQL
			sql = "select count(*) as rec_cnt from "+schema+".oo_meta_info";
			iRecCount = -1; // 0 ȉɂĂāAR[h擾łȂꍇƋʁiÔ߁j
			//R[h̗L
			try {
				ResultSet rs = stmt.executeQuery(sql);
				while(rs.next()) {
					iRecCount = rs.getInt("rec_cnt");
				}
			} catch (SQLException e) {
				//e[u݂Ȃꍇ͉Ȃi߂Ă̐ݒj
			}

			// iRecCount = -1 -> e[u݂Ȃ(Creates)
			// iRecCount =  0 -> e[u(Creates)
			if (iRecCount > 0) {
				iRetValue = 1000;
				strRetValue = "łɃ^f[^݂܂B";
				//f
				return;
			}


			//Error Log
			String logFileName = "metaTool.log";
			String strLogReturnMsg="";
			writeLog errlog = new writeLog();

			//Delete
			strLogReturnMsg=errlog.logDelete(logFileName);


			//XNvgs
			for (int iCount = 0; iCount < script.length; iCount++) {
				try {
					if (!script[iCount].equals("")) {
try {
	Thread.sleep(50); //sleep for a second
} catch (InterruptedException e) {}
						iCurrentCount++; // JEgAbv
						current = iCurrentCount;
						statMessage = current + "^" + lengthOfTask + " I܂B";
						script[iCount]=replace(script[iCount],"%schema%",schema);
						stmt.executeUpdate(script[iCount]);
					}
				} catch (SQLException e) {
Dbg.out("Error"+script[iCount]+e.toString());
					//Error Log
					strLogReturnMsg=errlog.errLogOpen(logFileName);
					errlog.output("************************************************");
					errlog.output("*** Message ***");
					errlog.output(e.toString());
					errlog.output("***** SQL *****");
					errlog.output(script[iCount]);
					errlog.fileClose();
				}
			}

			for (int iCount = 0; iCount < proc.length; iCount++) {
				try {
					if (!proc[iCount].equals("")) {
try {
	Thread.sleep(50); //sleep for a second
} catch (InterruptedException e) {}
						iCurrentCount++; // JEgAbv
						current = iCurrentCount;
						statMessage = current + "^" + lengthOfTask + " I܂B";
						proc[iCount]=replace(proc[iCount],"%schema%",schema);
						stmt.executeUpdate(proc[iCount]);
					}
				} catch (SQLException e) {
Dbg.out("Error"+proc[iCount]+e.toString());
					//Error Log
					strLogReturnMsg=errlog.errLogOpen(logFileName);
					errlog.output("************************************************");
					errlog.output("*** Message ***");
					errlog.output(e.toString());
					errlog.output("***** SQL *****");
					errlog.output(proc[iCount]);
					errlog.fileClose();
				}
			}

			for (int iCount = 0; iCount < time.length; iCount++) {
				try {
					if (!time[iCount].equals("")) {
try {
	Thread.sleep(50); //sleep for a second
} catch (InterruptedException e) {}
						iCurrentCount++; // JEgAbv
						current = iCurrentCount;
						statMessage = current + "^" + lengthOfTask + " I܂B";
						time[iCount]=replace(time[iCount],"%schema%",schema);
						ResultSet rs = stmt.executeQuery(time[iCount]);
						rs.close();
					}
				} catch (SQLException e) {
Dbg.out("Error"+time[iCount]+e.toString());
					//Error Log
					strLogReturnMsg=errlog.errLogOpen(logFileName);
					errlog.output("************************************************");
					errlog.output("*** Message ***");
					errlog.output(e.toString());
					errlog.output("***** SQL *****");
					errlog.output(time[iCount]);
					errlog.fileClose();
				}
			}

			//
			// Processing.....end
			// 

			// f[^x[Xؒf
			try {
				stmt.close();
				conn.close();
			} catch (SQLException e) {
				System.out.println("Caught exception " + e +".");
				iRetValue = 199;
				strRetValue = (String)e.getMessage();
			}

			//bZ[W\pɑҋ@
			try {
				Thread.sleep(1000); //sleep for a second
			} catch (InterruptedException e) {}
			iRetValue = 0;
			strRetValue = "";
		}

	}
	// NX͂܂

	String readFile (String pathName){
		try{
			//FileReader fr = new FileReader(pathName);
			//BufferedReader br = new BufferedReader(fr);

			FileInputStream fis = new FileInputStream(pathName);
			InputStreamReader isr = null;
				isr = new InputStreamReader(fis,"Shift_JIS");
				//isr = new InputStreamReader(fis);

			BufferedReader br = new BufferedReader(isr);

			String line="";
			StringBuffer allText= new StringBuffer(50000);

			line = "";
//			allText = line + "\n";
			while(line != null){
				line = br.readLine();
				if (line !=null){
					allText.append(line + "\n");
				}
			}
//System.out.println(pathName+":::::"+allText.length());
			return allText.toString();
		}catch(FileNotFoundException e){
		}catch(IOException e){
		}
		return null;
	}

	int init_script() {
	    script = split(this.readFile("createMetaTable.oo"), "/"+"\n");
		return script.length -1 ;
	}

	int init_proc() {
	    proc = split(this.readFile("createProcedure.oo"), "/"+"\n");
		return proc.length -1 ;
	}

	int init_time() {
	    time = split(this.readFile("createTimeData.oo"), "/"+"\n");
		return time.length -1 ;
	}

	private static String replace(String strTarget, String strOldStr, String strOldNew){
	    String strSplit[];
	    String strResult;

	    strSplit = split(strTarget, strOldStr);
	    strResult = strSplit[0];
	    for (int i = 1; i < strSplit.length; i ++)
	    {
	        strResult += strOldNew + strSplit[i];
	    }

	    return strResult;
	}

	private static String[] split(String strTarget, String strDelimiter){
	    String strResult[];
	    Vector objResult;
	    int intDelimiterLen;
	    int intStart;
	    int intEnd;

	    objResult = new java.util.Vector();
	    strTarget = strTarget + strDelimiter;
	    intDelimiterLen = strDelimiter.length();
	    intStart = 0;
	    while ((intEnd = strTarget.indexOf(strDelimiter, intStart)) >= 0)
	    {
	        objResult.addElement(strTarget.substring(intStart, intEnd));
	        intStart = intEnd + intDelimiterLen;
	    }

	    strResult = new String[objResult.size()];
	    objResult.copyInto(strResult);
	    return strResult;
	}


}
